# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# NOTE: This file is auto generated by the elixir code generator program.
# Do not edit this file manually.

defmodule GoogleApi.CivicInfo.V2.Api.Representatives do
  @moduledoc """
  API calls for all endpoints tagged `Representatives`.
  """

  alias GoogleApi.CivicInfo.V2.Connection
  alias GoogleApi.Gax.{Request, Response}

  @library_version Mix.Project.config() |> Keyword.get(:version, "")

  @doc """
  Looks up political geography and representative information for a single address.

  ## Parameters

  *   `connection` (*type:* `GoogleApi.CivicInfo.V2.Connection.t`) - Connection to server
  *   `optional_params` (*type:* `keyword()`) - Optional parameters
      *   `:alt` (*type:* `String.t`) - Data format for the response.
      *   `:fields` (*type:* `String.t`) - Selector specifying which fields to include in a partial response.
      *   `:key` (*type:* `String.t`) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
      *   `:oauth_token` (*type:* `String.t`) - OAuth 2.0 token for the current user.
      *   `:prettyPrint` (*type:* `boolean()`) - Returns response with indentations and line breaks.
      *   `:quotaUser` (*type:* `String.t`) - An opaque string that represents a user for quota purposes. Must not exceed 40 characters.
      *   `:userIp` (*type:* `String.t`) - Deprecated. Please use quotaUser instead.
      *   `:address` (*type:* `String.t`) - The address to look up. May only be specified if the field ocdId is not given in the URL.
      *   `:includeOffices` (*type:* `boolean()`) - Whether to return information about offices and officials. If false, only the top-level district information will be returned.
      *   `:levels` (*type:* `list(String.t)`) - A list of office levels to filter by. Only offices that serve at least one of these levels will be returned. Divisions that don't contain a matching office will not be returned.
      *   `:roles` (*type:* `list(String.t)`) - A list of office roles to filter by. Only offices fulfilling one of these roles will be returned. Divisions that don't contain a matching office will not be returned.
      *   `:body` (*type:* `GoogleApi.CivicInfo.V2.Model.RepresentativeInfoRequest.t`) - 
  *   `opts` (*type:* `keyword()`) - Call options

  ## Returns

  *   `{:ok, %GoogleApi.CivicInfo.V2.Model.RepresentativeInfoResponse{}}` on success
  *   `{:error, info}` on failure
  """
  @spec civicinfo_representatives_representative_info_by_address(
          Tesla.Env.client(),
          keyword(),
          keyword()
        ) ::
          {:ok, GoogleApi.CivicInfo.V2.Model.RepresentativeInfoResponse.t()}
          | {:ok, Tesla.Env.t()}
          | {:error, any()}
  def civicinfo_representatives_representative_info_by_address(
        connection,
        optional_params \\ [],
        opts \\ []
      ) do
    optional_params_config = %{
      :alt => :query,
      :fields => :query,
      :key => :query,
      :oauth_token => :query,
      :prettyPrint => :query,
      :quotaUser => :query,
      :userIp => :query,
      :address => :query,
      :includeOffices => :query,
      :levels => :query,
      :roles => :query,
      :body => :body
    }

    request =
      Request.new()
      |> Request.method(:get)
      |> Request.url("/representatives", %{})
      |> Request.add_optional_params(optional_params_config, optional_params)
      |> Request.library_version(@library_version)

    connection
    |> Connection.execute(request)
    |> Response.decode(
      opts ++ [struct: %GoogleApi.CivicInfo.V2.Model.RepresentativeInfoResponse{}]
    )
  end

  @doc """
  Looks up representative information for a single geographic division.

  ## Parameters

  *   `connection` (*type:* `GoogleApi.CivicInfo.V2.Connection.t`) - Connection to server
  *   `ocd_id` (*type:* `String.t`) - The Open Civic Data division identifier of the division to look up.
  *   `optional_params` (*type:* `keyword()`) - Optional parameters
      *   `:alt` (*type:* `String.t`) - Data format for the response.
      *   `:fields` (*type:* `String.t`) - Selector specifying which fields to include in a partial response.
      *   `:key` (*type:* `String.t`) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
      *   `:oauth_token` (*type:* `String.t`) - OAuth 2.0 token for the current user.
      *   `:prettyPrint` (*type:* `boolean()`) - Returns response with indentations and line breaks.
      *   `:quotaUser` (*type:* `String.t`) - An opaque string that represents a user for quota purposes. Must not exceed 40 characters.
      *   `:userIp` (*type:* `String.t`) - Deprecated. Please use quotaUser instead.
      *   `:levels` (*type:* `list(String.t)`) - A list of office levels to filter by. Only offices that serve at least one of these levels will be returned. Divisions that don't contain a matching office will not be returned.
      *   `:recursive` (*type:* `boolean()`) - If true, information about all divisions contained in the division requested will be included as well. For example, if querying ocd-division/country:us/district:dc, this would also return all DC's wards and ANCs.
      *   `:roles` (*type:* `list(String.t)`) - A list of office roles to filter by. Only offices fulfilling one of these roles will be returned. Divisions that don't contain a matching office will not be returned.
      *   `:body` (*type:* `GoogleApi.CivicInfo.V2.Model.DivisionRepresentativeInfoRequest.t`) - 
  *   `opts` (*type:* `keyword()`) - Call options

  ## Returns

  *   `{:ok, %GoogleApi.CivicInfo.V2.Model.RepresentativeInfoData{}}` on success
  *   `{:error, info}` on failure
  """
  @spec civicinfo_representatives_representative_info_by_division(
          Tesla.Env.client(),
          String.t(),
          keyword(),
          keyword()
        ) ::
          {:ok, GoogleApi.CivicInfo.V2.Model.RepresentativeInfoData.t()}
          | {:ok, Tesla.Env.t()}
          | {:error, any()}
  def civicinfo_representatives_representative_info_by_division(
        connection,
        ocd_id,
        optional_params \\ [],
        opts \\ []
      ) do
    optional_params_config = %{
      :alt => :query,
      :fields => :query,
      :key => :query,
      :oauth_token => :query,
      :prettyPrint => :query,
      :quotaUser => :query,
      :userIp => :query,
      :levels => :query,
      :recursive => :query,
      :roles => :query,
      :body => :body
    }

    request =
      Request.new()
      |> Request.method(:get)
      |> Request.url("/representatives/{ocdId}", %{
        "ocdId" => URI.encode(ocd_id, &URI.char_unreserved?/1)
      })
      |> Request.add_optional_params(optional_params_config, optional_params)
      |> Request.library_version(@library_version)

    connection
    |> Connection.execute(request)
    |> Response.decode(opts ++ [struct: %GoogleApi.CivicInfo.V2.Model.RepresentativeInfoData{}])
  end
end
